Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(173)

Unified Diff: content/public/browser/notification_types.h

Issue 9030032: Get rid of a bunch of tab_contents.h includes from chrome. These are all trivial changes to use W... (Closed) Base URL: svn://chrome-svn/chrome/trunk/src/
Patch Set: fix cros Created 8 years, 12 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/public/browser/download_manager_delegate.h ('k') | content/shell/shell_download_manager_delegate.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/public/browser/notification_types.h
===================================================================
--- content/public/browser/notification_types.h (revision 116331)
+++ content/public/browser/notification_types.h (working copy)
@@ -224,11 +224,11 @@
NOTIFICATION_TAB_CLOSED,
// This notification is sent when a render view host has connected to a
// renderer process. The source is a Source<TabContents> with a pointer to
// the TabContents. A TAB_CONTENTS_DISCONNECTED notification is
// guaranteed before the source pointer becomes junk. No details are
// expected.
- NOTIFICATION_TAB_CONTENTS_CONNECTED,
+ NOTIFICATION_WEB_CONTENTS_CONNECTED,
// This notification is sent when a TabContents swaps its render view host
// with another one, possibly changing processes. The source is a
« no previous file with comments | « content/public/browser/download_manager_delegate.h ('k') | content/shell/shell_download_manager_delegate.h » ('j') | no next file with comments »
@@ -224,11 +224,11 @@
NOTIFICATION_TAB_CLOSED,
// This notification is sent when a render view host has connected to a
- // renderer process. The source is a Source<TabContents> with a pointer to
- // the TabContents. A TAB_CONTENTS_DISCONNECTED notification is
+ // renderer process. The source is a Source<WebContents> with a pointer to
+ // the WebContents. A WEB_CONTENTS_DISCONNECTED notification is
// guaranteed before the source pointer becomes junk. No details are
// expected.

Powered by Google App Engine
This is Rietveld 408576698